gAPhAsOutput <- function(fit, phCoefName="^Ph", IsolCoefName="^Isol", flipPhCoefSign=TRUE){
  ## Calculate, the gA value as the steady-state gain from the estimated transfer function
  ## for the solar radiation input
  ##

##  browser()
  ## Find the indexes for the coefficients for the inputs and output
  iPh <- grep(phCoefName, names(fit$coefficients))
  iOmegaIsol <- grep(IsolCoefName, names(fit$coefficients))
  ## Number of coefficients
  np <- length(fit$coefficients)

  ## Flip the sign of the Ph coefficients if specified (In an ARX model estimated with lm their sign is flipped)
  if(flipPhCoefSign){ fit$coefficients[iPh] <- -fit$coefficients[iPh] }

  ## The AR (Ph) and input (omega) polynomials with a 1 through
  PhSum <- sum(c(1,fit$coefficients[iPh]))
  omegaIsolSum <- sum(fit$coefficients[iOmegaIsol])

  ## The estimated steady-state gain for the transfer function
  gA <- -omegaIsolSum / PhSum

  ## The Jacobian, note that it contains an element for each coefficient, hence many zeroes
  J <- matrix(0,nrow=1,ncol=np)
  J[1,iPh] <- -omegaIsolSum / PhSum^2
  J[1,iOmegaIsol] <- PhSum / PhSum^2

  ## The covariance matrix of the estimated parameters
  ## If from the fit is a list (from ARMAX)
  if(class(fit)=="list") covar <- fit$covar
  else covar <- vcov(fit)
  ## Flip the AR sign is specified
  if(flipPhCoefSign)
    {
      covar[iPh,] <- covar[iPh,] * -1
      covar[,iPh] <- covar[,iPh] * -1
    }
  
  VargA <- J%*%covar%*%t(J)
  sdgA <- sqrt(VargA)  

  ## ## The covariance between Uc and g
  ## jac.Usg <- rbind(jac.us,jac.g)
  ## Var.Usg <- jac.Usg%*%covar%*%t(jac.Usg)
  ## ## Use: cov(a*X+b*Y,Z) = a*cov(X,Y) + b*cov(Y,Z)
  ## cov.Ug <- lambda * Var.Usg[1,3] + (1-lambda) * Var.Usg[2,3]
  ## ## The correlation
  ## cor.Ug <- cov.Ug/(sd.U*sd.g)
  
  return(list(gA = gA, sdgA = sdgA))
}
