sdeTi <- function(X,rerun=FALSE){
  ## Load a cached result, if it is class ctsmr, then it is a loaded fit
  if(class(fitCacheName <- sdeCache(X,rerun))=="ctsmr"){ return(fitCacheName) }
  ## Generate a new object of class ctsm
  model <- ctsm$new()
  ## Add system equations and thereby also states
  model$addSystem(dTi ~ 1/(Ci*1E9) * ( 1/Rie*(Te-Ti) + gA*Isol + Ph )*dt + exp(p11)*dw1)
  ## Set the names of the inputs
  model$addInput(Te,Isol,Ph)

  ## Set the observation equation: Ti is the state, yTi is the measured output
  model$addObs(yTi ~ Ti)
  ## Set the variance of the measurement error
  model$setVariance(yTi ~ exp(e11))

  ## Set the initial value (for the optimization) of the value of the state at the starting time point
  model$setParameter(  Ti = c(init=35  ,lb=10    ,ub=45) )
  ## Set the initial value of the parameters for the optimization
  model$setParameter(  Ci = c(init=0.1 ,lb=1E-3   ,ub=1) )
  model$setParameter( Rie = c(init=1/150 ,lb=1E-4  ,ub=1/10) )
  model$setParameter(  gA = c(init=1   ,lb=0.01 ,ub=40))
  model$setParameter( p11 = c(init=1   ,lb=-50   ,ub=10) )
  model$setParameter( p22 = c(init=1   ,lb=-50   ,ub=10) )
  model$setParameter( e11 = c(init=-1  ,lb=-50   ,ub=10) )

  ## Run the parameter optimization
  fit <- model$estimate(data = X, firstorder=pg$firstorder, threads = pg$threads)
  fit$data[[1]] <- X
  fit$Rnames <- c("Rie")
  ## Save the fit
  save(fit,file=fitCacheName)
  
  ## Return
  return(fit)
}
