sdeTiThTw <- function(X)
    {
        ## Generate a new object of class ctsm
        model <- ctsm$new()
        ## Add a system equation and thereby also a state
        model$addSystem(dTi ~ 1/(Ci*1E6)*( 1/Rih*(Th-Ti) + 1/Riw*(Tw-Ti) + Aw*Isol )*dt + exp(p11)*dw1 )
        model$addSystem(dTh ~ 1/(Ch*1E6)*( 1/Rih*(Ti-Th) + Ph)*dt + exp(p22)*dw2 )
        model$addSystem(dTw ~ 1/(Cw*1E6)*( 1/Riw*(Ti-Tw) + 1/Rwe*(Te-Tw) )*dt + exp(p33)*dw3 )
        ## Set the names of the inputs
        model$addInput(Te,Isol,Ph)
        ## Set the observation equation: Ti is the state, yTi is the measured output
        model$addObs(yTi ~ Ti)
        ## Set the variance of the measurement error
        model$setVariance(yTi ~ exp(e11))
        ## Set the initial value (for the optimization) of the value of the state at the starting time point
        model$setParameter(  Ti = c(init=X$yTi[1]+0.1  ,lb=10    ,ub=40) )
        model$setParameter(  Tw = c(init=X$yTi[1]-10 ,lb=5     ,ub=40) )
        model$setParameter(  Th = c(init=X$yTi[1]+0.1  ,lb=10    ,ub=400) )
        ## Set the initial value for the optimization
        model$setParameter(  Ci = c(init=0.1   ,lb=0.001  ,ub=30) )
        model$setParameter(  Ch = c(init=0.1 ,lb=1E-4  ,ub=10) )
        model$setParameter(  Cw = c(init=5  ,lb=0.01    ,ub=100) )
        model$setParameter( Rih = c(init=1/500,lb=1E-6  ,ub=10))
        model$setParameter( Riw = c(init=1/10,lb=1/1E3 ,ub=1) )
        model$setParameter( Rwe = c(init=1/140,lb=1/1E3 ,ub=1/10) )
        model$setParameter(  Aw = c(init=1   ,lb=0.01  ,ub=10))
        model$setParameter( p11 = c(init=1   ,lb=-50   ,ub=20) )
        model$setParameter( p22 = c(init=-1  ,lb=-50   ,ub=20) )
        model$setParameter( p33 = c(init=1   ,lb=-50   ,ub=20) )
        model$setParameter( e11 = c(init=-1  ,lb=-50   ,ub=20) )
        
        ## Run the parameter optimization
        fit <- model$estimate(data = X, firstorder=pg$firstorder, threads = pg$threads)
        fit$data[[1]] <- X
        fit$Rnames <- c("Rwe","Riw")
        ## Return
        return(fit)
    }
