sdeTiTw <- function(X,rerun=FALSE){
  ## Load a cached result, if it is class ctsmr, then it is a loaded fit
  if(class(fitCacheName <- sdeCache(X,rerun))=="ctsmr") return(fitCacheName)
  ## Generate a new object of class ctsm
  model <- ctsm$new()
  ## Add system equations and thereby also states
  model$addSystem(dTi ~ 1/(Ci*1E9) * (1/Riw*(Tw-Ti) + gA*Isol + Ph )*dt + exp(p11)*dw1)
  model$addSystem(dTw ~ 1/(Cw*1E9) * (1/Riw*(Ti-Tw) + 1/Rwe*(Te-Tw) )*dt + exp(p22)*dw2)
  ## Set the names of the inputs
  model$addInput(Te,Isol,Ph)

  ## Set the observation equation: Ti is the state, yTi is the measured output
  model$addObs(yTi ~ Ti)
  ## Set the variance of the measurement error
  model$setVariance(yTi ~ exp(e11))

  ## Set the initial value (for the optimization) of the value of the state at the starting time point
  model$setParameter(  Ti = c(init=X$yTi[1]+0.1  ,lb=10    ,ub=40) )
  model$setParameter(  Tw = c(init=X$yTi[1]-2  ,lb=5     ,ub=40) )
  ## Set the initial value of the parameters for the optimization
  model$setParameter(  Ci = c(init=0.001 ,lb=1E-4   ,ub=10) )
  model$setParameter(  Cw = c(init=0.005  ,lb=1E-4   ,ub=10) )
  model$setParameter( Riw = c(init=0.001 ,lb=1E-6  ,ub=0.5) )
  model$setParameter( Rwe = c(init=0.01 ,lb=1E-5  ,ub=0.5) )
  model$setParameter( gA = c(init=3,lb=0.01 ,ub=30))
  model$setParameter( p11 = c(init=1   ,lb=-50   ,ub=10) )
  model$setParameter( p22 = c(init=1   ,lb=-50   ,ub=10) )
  model$setParameter( e11 = c(init=1   ,lb=-50   ,ub=10) )
  
  ## Run the parameter optimization
  fit <- model$estimate(data = X, firstorder=pg$firstorder, threads = pg$threads)
  fit$data[[1]] <- X
  fit$Rnames <- c("Rwe","Riw")
  fit$Gnames <- c("gA")
  ## Save the fit
  save(fit,file=fitCacheName)
  
  ## Return
  return(fit)
}
