sdeTiTw3Isol <- function(X,rerun=FALSE,constantsampling=TRUE)
    {
        ## Load a cached result, if it is class ctsmr, then it is a loaded fit
        if(class(fitCacheName <- sdeCache(X,rerun))=="ctsmr") return(fitCacheName)
        ## Generate a new object of class ctsm
        model <- ctsm$new()
        ## Add system equations and thereby also states
        model$addSystem(dTi ~ 1/(Ci*1E6) * (1/Riw*(Tw-Ti) + gA1*Isol1 + gA2*Isol2 + gA3*Isol3 + Ph )*dt + exp(p11)*dw1)
        model$addSystem(dTw ~ 1/(Cw*1E6) * (1/Riw*(Ti-Tw) + 1/Rwe*(Te-Tw) )*dt + exp(p22)*dw2)
        ## Set the names of the inputs
        model$addInput(Te,Isol1,Isol2,Isol3,Ph)

        ## Set the observation equation: Ti is the state, yTi is the measured output
        model$addObs(yTi ~ Ti)
        ## Set the variance of the measurement error
        model$setVariance(yTi ~ exp(e11))

        ## Set the initial value (for the optimization) of the value of the state at the starting time point
        model$setParameter(  Ti = c(init=X$yTi[1]+0.1  ,lb=10    ,ub=40) )
        model$setParameter(  Tw = c(init=X$yTi[1]-5  ,lb=5     ,ub=40) )
        ## Set the initial value of the parameters for the optimization
        model$setParameter(  Ci = c(init=5   ,lb=0.01   ,ub=30) )
        model$setParameter(  Cw = c(init=5  ,lb=0.01   ,ub=100) )
        model$setParameter( Riw = c(init=0.01 ,lb=1E-5  ,ub=1) )
        model$setParameter( Rwe = c(init=0.01 ,lb=1E-5  ,ub=1) )
        model$setParameter( gA1 = c(init=3,lb=0.01 ,ub=30))
        model$setParameter( gA2 = c(init=3,lb=0.01 ,ub=30))
        model$setParameter( gA3 = c(init=3,lb=0.01 ,ub=30))
        model$setParameter( p11 = c(init=1   ,lb=-50   ,ub=10) )
        model$setParameter( p22 = c(init=1   ,lb=-50   ,ub=10) )
        model$setParameter( e11 = c(init=-1  ,lb=-50   ,ub=10) )
        
        ## Run the parameter optimization
        fit <- model$estimate(data = X, firstorder=pg$firstorder, threads = pg$threads)
        fit$data[[1]] <- X
        fit$Rnames <- c("Rwe","Riw")
        fit$Gnames <- c("gA")
        ## Save the fit
        save(fit,file=fitCacheName)
        
        ## Return
        return(fit)
    }
