###########################################################################
## Function for calculating the step response of the estimated transfer function of the given input
stepResponsePhAsOutput <- function(fit, Ts=NA, outName="^Ph", inName="^Te", ylim=NA, plotStepResponse=TRUE){
  TsHours <- Ts / 3600
  ## Index of AR coefficients in the fit
  iPhi <- grep(outName, names(fit$coefficients))
  ##
  ## Coefficients of the AR and input polynomials
  coefPhi <- fit$coefficients[iPhi]
  coefInput <- fit$coefficients[grep(paste("^",inName,sep=""),names(fit$coefficients))]
  ## Calculate and plot the step response in hours
  input <- c(rep(0,4/TsHours),rep(1,20/TsHours))
  PhiHat <- rep(0,length(input))
  for(i in 5:length(input))
    {
      ## The index from now and back
      PhiHat[i] <- sum(c(coefPhi * PhiHat[(i-1):(i-length(coefPhi))], coefInput * input[i:(i-length(coefInput)+1)]))
    }
  tHours <- (1:length(input))*TsHours
  if(plotStepResponse){
    ## Plot
    if(is.na(ylim[1])) ylim <- range(input,PhiHat)
    plot(tHours-(4+TsHours),input,ylim=ylim,main=paste("Step response for",inName),xlab="hours",ylab="Input and output",type="s")
    lines(tHours-(4+TsHours),PhiHat,col=2,type="s")
    legend("topright",gsub("\\^","",c(inName,outName)),lty=1,col=1:2,bg="white")
  }
}
