tsPlotResiduals <- function(fit,X,i=NA,gridTs=NA,...)
  {
    r <- fit$residuals
    if(length(fit$na.action) > 0){ X <- X[-fit$na.action,] }
    ## Take a period
    if(!is.na(i[1]))
      {
        r <- r[i]
        X <- X[i,]
      }
    ##
    setpar(mfrow=c(3,1))
    ## The inputs
    ylimIn <- c(-0.05,1.05)
    xlim <- c(min(X$t),max(X$t)+diff(range(X$t))*0.15)
    ##
    plot(X$t,r,type="n",ylim=ylimIn,xlim=xlim,xlab="",ylab="Inputs",yaxt="n",bty="n")
    if(!is.na(gridTs)) abline(v=seq(trunc(min(X$t),units="days"),max(X$t),by=gridTs), col="grey90", lwd=0.3)
    box()
    ##
    nams <- names(fit$coefficients)
    rmv <- c("^Ph","^Te","^Isol")
    for(i in 1:length(rmv)) if(length(grep(rmv[i],nams))>1) nams <- nams[-grep(rmv[i],nams)[-1]]
    ## Remove MA
    if( ("MA.l1" %in% nams) ) nams <- nams[-grep("^MA",nams)]
    ##
    for(i in 1:length(nams))
      {
        lines(X$t,norm(X[,nams[i]],c(0,1)), col=i, ...)
      }
    legend("bottomright",gsub(".l[0-9]","",nams),lty=1,col=1:length(nams),bg="white")
    ## Output and predicted
#    browser()
    ylimPh <- range(X$Ph, X$Ph-r, na.rm=TRUE)
    plot(X$t,X$Ph,ylim=ylimPh,xlim=xlim,type="n",xlab="",ylab="$\\Phi_{\\mathrm{h}}$ (W)",yaxt="n",bty="n")
    if(!is.na(gridTs)) abline(v=seq(trunc(min(X$t),units="days"),max(X$t),by=gridTs), col="grey90", lwd=0.3)
    box()
    ##
    axis(2, pretty(scalerange(ylimPh,0.2)))
    lines(X$t, X$Ph, ...)
    lines(X$t, X$Ph-r, col=2, ...)
    legend("bottomright", c("Measured","Predicted"), lty=1, col=1:2, bg="white", cex=0.8)
    ## The residuals
    ylimRes <- c(min(r),max(r))
    plot(X$t, r, ylim=ylimRes, xlim=xlim, type="n", xlab="", ylab="$\\hat{\\epsilon}_t$", yaxt="n", bty="n")
    abline(h=0, col="grey90")
    if(!is.na(gridTs)) abline(h=0,v=seq(trunc(min(X$t),units="days"),max(X$t),by=gridTs), col="grey90", lwd=0.3)
    box()
    axis(2, pretty(scalerange(ylimRes,0.2)))
    ##
    lines(X$t,r, ...)
    ## 
    axis.POSIXct(side=1, x=X$t, xaxt="s")

    ##
    X$r <- r
    invisible(X)
  }
