## @knitr linearDynamicForBox_init
## Load the helping functions
source("sourceFunctions.R")
## Read the data
selNames <- c("Ph","Ti","Te","Isol")
## The sampling time in seconds, use 1 hour average values
Ts <- 3600
## The 3rd common exercise with 25 C constant internal temperature
X <- readSeries("ce3b25C", Ts=3600, selNames)
## See the first six rows of X
head(X)

## @knitr linearDynamicForBox_makeLagged
## Make lagged series
X <- makeLagged(X, selNames, nlags=4)
## Remove beginning such that the same period is always removed independent of the sample period
X <- X[asP("2013-01-29 12:00") < X$t, ]
## See the column names
names(X)
## Now see the first six rows of X for lagged Ti 
head(X[ , grep("^Ti.l",names(X))])

## @knitr linearDynamicForBox_plot
setpar(mfrow=c(3,1))
plot(X$t, X$Ph, type="b", xlab="", ylab="$\\Phi_t$ (W)")
plot(X$t, X$Ti, type="b", ylim=range(X$Ti,X$Te), xlab="", ylab="Temperature (C)")
lines(X$t, X$Te, type="b", col=2)
legend("right", c("Internal","External"), col=1:2, lty=1)
plot(X$t, X$Isol, ylab="$I_{\\mathrm{sol}} = G_{\\mathrm{vs}}$ (W/m$^2$)", xlab="", type="b")
axis.POSIXct(1, X$t, xaxt="s")

## @knitr linearDynamicForBox_fit0
## Fit a linear steady-state model
fit0 <- lm(Ph ~ 0 + Ti + Te + Isol, X)
## The ACF and CCF
acfccf(fit0, X)

## @knitr linearDynamicForBox_fit1Frml
(frml <- frmlARX(outName="Ph", inNames=c("Te","Isol"), p=1, inNonLagNames="Ti"))

## @knitr linearDynamicForBox_fit1
## Fit a linear steady-state model
fit1 <- lm(frml, X)
## The ACF and CCF
acfccf(fit1, X)

## @knitr linearDynamicForBox_fit2
fit2 <- lm(frmlARX(outName="Ph", inNames=c("Te","Isol"), p=2, inNonLagNames="Ti"), X)
## The ACF and CCF
acfccf(fit2, X)

## @knitr linearDynamicForBox_fit3
fit3 <- lm(frmlARX(outName="Ph", inNames=c("Te","Isol"), p=3, inNonLagNames="Ti"), X)
## The ACF and CCF
acfccf(fit3, X)

## @knitr linearDynamicForBox_fit3Summary
summary(fit3)

## @knitr linearDynamicForBox_fit2Summary
summary(fit2)

## @knitr linearDynamicForBox_cpgram
par(mar=c(3.5,3.5,1.5,0.5), cex=0.75)
cpgram(fit2$residuals, main="Residuals CPGRAM for $p=2$")

## @knitr linearDynamicForBox_TSPlot
tsPlotResiduals(fit2, X, type="b")

## @knitr linearDynamicForBox_HTC
HTCPhAsOutput(fit2)

## @knitr linearDynamicForBox_gA
gAPhAsOutput(fit2)

## @knitr linearDynamicForBox_timeConstants
timeConstantsPhAsOutput(fit2, Ts)

## @knitr linearDynamicForBox_stepResponse
par(mfrow=c(2,1), mar=c(3.5,3.5,1.5,0.5), cex=0.8)
stepResponsePhAsOutput(fit2, Ts, inName="Te")
stepResponsePhAsOutput(fit2, Ts, inName="Isol")

## @knitr more
plot(fit2$fitted.values, fit2$residuals)
plot(X$Isol, fit2$residuals)



## @knitr linearDynamicForBox_deltaT
## Calculate the delta T
X$deltaT <- X$Ti - X$Te
selNames <- c(selNames,"deltaT")
X <- makeLagged(X, selNames, nlags=3)
X <- X[asP("2013-01-29 12:00") < X$t, ]


## @knitr linearDynamicForBox_deltaTFit
fitDeltaT <- lm(frmlARX(outName="Ph", inNames=c("deltaT","Isol"), p=3), X)

acfccf(fitDeltaT, X)

## @knitr linearDynamicForBox_deltaTSummary
## See the result
summary(fitDeltaT)

## @knitr linearDynamicForBox_deltaTHTC
HTCPhAsOutput(fitDeltaT, TeCoefName="deltaT")

## @knitr linearDynamicForBox_delTagA
gAPhAsOutput(fitDeltaT)
