## @knitr linearSteadyStateExample_init
## Load the helping functions
source("sourceFunctions.R")
## Read the data from the 3rd common exercise as 6 hours average values
X <- readSeries("ce3b25C", Ts=6*3600, selNames=c("t","Ph","Ti","Te","Isol"))
## Remove beginning such that the same period is always removed independent of the sample period
X <- X[asP("2013-01-29 12:00") < X$t, ]

## @knitr linearSteadyStateExample_plot
setpar(mfrow=c(3,1))
plot(X$t, X$Ph, type="b", xlab="", ylab="$\\Phi_\\mathrm{h}$ (W)")
plot(X$t, X$Ti, type="b", ylim=range(X$Ti,X$Te), xlab="", ylab="Temperature ($^\\circ$C)")
lines(X$t, X$Te, type="b", col=2)
legend("right", c("Internal","External"), col=1:2, lty=1)
plot(X$t, X$Isol, ylab="$I_{\\mathrm{sol}} = G_{\\mathrm{vs}}$ (W/m$^2$)", xlab="", type="b")
axis.POSIXct(1, X$t, xaxt="s")

## @knitr linearSteadyStateExample_fit
## Fit a linear steady-state model
fit <- lm(Ph ~ 0 + Ti + Te + Isol, data=X)
## See the result
summary(fit)

## @knitr linearSteadyStateExample_ACFCCF
## Plot ACF and CCF to inputs (wrapped in the function acfccf())
acfccf(fit, X)

## @knitr linearSteadyStateExample_TSPlot
tsPlotResiduals(fit, X, type="b")

## @knitr linearSteadyStateExample_HTC
## Calculate the HTC using minimum variance linear weighting
HTCPhAsOutput(fit)

## @knitr linearSteadyStateExample_gA
## Calculate the gA value and its uncertainty
gAPhAsOutput(fit)

## @knitr linearSteadyStateExample_deltaT
## Calculate the delta T
X$deltaT <- X$Ti - X$Te

## @knitr linearSteadyStateExample_deltaTFit
## Fit a linear steady-state model
fitDeltaT <- lm(Ph ~ 0 + deltaT + Isol, data=X)

## @knitr linearSteadyStateExample_deltaTSummary
## See the result
summary(fitDeltaT)
